@@ -11,7 +11,7 @@ token = os.environ["MMISDK_TOKEN_SATURN_DEV"]
 custodian = factory.create_for("saturn-dev", token)
 
 # Get the transaction
-transaction = custodian.get_transaction("5377c945-f756-4c25-902d-c0d3b9cd179b")
+transaction = custodian.get_transaction("94f1316b-98af-4736-8116-6faf72eab60c")
 
 print(type(transaction))
 # <class 'mmisdk.common.transaction.Transaction'>
