@@ -1,4 +1,5 @@
-from pydantic import BaseModel
+
+from mmisdk.common.base_model import BaseModel
 
 
 class BitgoCreateTxExtraParams(BaseModel):
