@@ -1,6 +1,4 @@
-from typing import List
 
-import requests
 
 from mmisdk.adapters.qredo_create_tx_extra_params import QredoCreateTxExtraParams
 from mmisdk.common.custodian import Custodian
@@ -55,10 +53,10 @@ class QredoAdapter(Custodian):
             value=qredo_transaction_info.value,
             gas=qredo_transaction_info.gasLimit,
             gasPrice=qredo_transaction_info.gasPrice,
-            maxPriorityFeePerGas=None,
-            maxFeePerGas=None,
+            maxPriorityFeePerGas=qredo_transaction_info.maxPriorityFeePerGas,
+            maxFeePerGas=qredo_transaction_info.maxFeePerGas,
             nonce=qredo_transaction_info.nonce,
-            data=qredo_transaction_info.data,
-            hash=qredo_transaction_info.txHash,
+            data=qredo_transaction_info.data if qredo_transaction_info.data != "" else None,
+            hash=qredo_transaction_info.txHash if qredo_transaction_info.txHash != "" else None,
             status=map_transaction_status(qredo_transaction_info.status, "Unknown"),
         )
