@@ -1,9 +1,11 @@
-from typing import Generic, List, TypeVar
+from typing import Generic
+from typing import List
+from typing import TypeVar
+
 from pydantic.generics import GenericModel
 
 from mmisdk.bitgo.bitgo_response_meta import BitgoResponseMeta
 
-
 T = TypeVar("T")
 
 
