@@ -1,6 +1,6 @@
 
 
-from pydantic import BaseModel
+from mmisdk.common.base_model import BaseModel
 
 
 class BitgoResponseMeta(BaseModel):
