@@ -1,9 +1,10 @@
-from typing import Dict, Optional
+from typing import Dict
+from typing import Optional
 
 from pydantic import Field
+
 from mmisdk.common.base_model import BaseModel
 from mmisdk.common.dec_string import DecString
-
 from mmisdk.common.ethereum_address import EthereumAddress
 from mmisdk.common.hex_string import HexString
 
