@@ -7,10 +7,16 @@ from mmisdk.cactus.cactus_transaction_detail import CactusTransactionDetail
 from mmisdk.cactus.cactus_tx_params import CactusTXParams
 from mmisdk.common.abstract_client import AbstractClient
 from mmisdk.utils.inject_from_ import inject_from_on_all
+from cachetools import TTLCache
 
 
 class CactusClient(AbstractClient):
 
+    def __init__(self, api_url, token):
+        self.api_url = api_url
+        self.token = token
+        self.cache = TTLCache(maxsize=1, ttl=86400)
+
     def __create_access_token(self):
         """Internal method that creates an access token, necessary to authenticate other calls against Cactus Custody's API.
 
@@ -32,13 +38,23 @@ class CactusClient(AbstractClient):
         access_token = response_json["jwt"]
         return access_token
 
+    def __create_access_token_cached(self):
+        """Lazily fetch the access token, looking up in the cache before. If the access is not in the cache, we fetch it then store it.
+        Note that we have to dynamically re-recreate the cache after fetching the token, because the TTL we want to use is extracted from the token's expires_in.
+        """
+        if 'access_token' not in self.cache:
+            access_token = self.__create_access_token()
+            self.cache['access_token'] = access_token
+
+        return self.cache['access_token']
+
     def __get_headers(self):
         """Internal method that creates the HTTP header to use for the calls against Cactus Custody's API. It includes an authorization header that uses the access token.
 
         Returns:
             The HTTP header as a dictionary.
         """
-        access_token = self.__create_access_token()
+        access_token = self.__create_access_token_cached()
         return {
             "Content-Type": "application/json",
             "Authorization": 'Bearer ' + access_token
