@@ -1,4 +1,8 @@
-from typing import Generic, Optional, TypeVar, Union
+from typing import Generic
+from typing import Optional
+from typing import TypeVar
+from typing import Union
+
 from pydantic.generics import GenericModel
 
 T = TypeVar("T")
