@@ -1,5 +1,8 @@
 from typing import Optional
-from pydantic import AnyHttpUrl, HttpUrl
+
+from pydantic import AnyHttpUrl
+from pydantic import HttpUrl
+
 from mmisdk.common.base_model import BaseModel
 
 
