@@ -1,6 +1,7 @@
-from typing import Any, List
-from mmisdk.common.base_model import BaseModel
+from typing import Any
+from typing import List
 
+from mmisdk.common.base_model import BaseModel
 from mmisdk.mmiconfig.custodian_config import CustodianConfig
 
 
