@@ -7,7 +7,7 @@ def mock_qredo_requests_post(*args, **kwargs):
 
     # Mock the request that creates the access token
     if args[0].__contains__('/connect/token'):
-        return MockResponse({"access_token": "some-access-token"}, 200)
+        return MockResponse({"access_token": "some-access-token", "expires_in": 86400}, 200)
 
     # Mock the request that creates a transaction
     if args[0].__contains__('/connect/transaction'):
