@@ -1,7 +1,9 @@
 from enum import Enum
-from typing import Dict, Union
+from typing import Dict
 from typing import List
 from typing import Optional
+from typing import Union
+
 from pydantic import Field
 
 from mmisdk.common.base_model import BaseModel
